@@ -22,8 +22,7 @@
 
 
 package Data::FormValidator;
-use base 'Exporter';
-
+use Exporter 'import';
 use 5.008;
 
 use Perl6::Junction qw(any none);
@@ -32,7 +31,7 @@ use Data::FormValidator::Results;
 use Data::FormValidator::Filters ':filters';
 use Data::FormValidator::Constraints qw(:validators :matchers);
 
-our $VERSION = '4.80';
+our $VERSION = '4.81';
 
 our %EXPORT_TAGS = (
     filters => [qw/
