@@ -23,7 +23,7 @@ use overload
   'bool' => \&_bool_overload_based_on_success,
   fallback => 1;
 
-our $VERSION = 4.70;
+our $VERSION = 4.81;
 
 =pod
 
@@ -415,7 +415,7 @@ sub success {
 
 =head1  valid( [[field] [, value]] );
 
-In an array context with no arguments, it returns the list of fields which
+In list context with no arguments, it returns the list of fields which
 contain valid values:
 
  @all_valid_field_names = $r->valid;
@@ -431,7 +431,7 @@ array ref if the field had multiple values:
 
  $value = $r->valid('field');
 
-If called with one argument in array context, it returns the values of C<field>
+If called with one argument in list context, it returns the values of C<field>
 as an array:
 
  @values = $r->valid('field');
@@ -475,7 +475,7 @@ sub has_missing {
 
 =head1 missing( [field] )
 
-In an array context it returns the list of fields which are missing.
+In list context it returns the list of fields which are missing.
 In a scalar context, it returns an array reference to the list of missing fields.
 
 If called with an argument, it returns true if that C<field> is missing,
@@ -507,7 +507,7 @@ sub has_invalid {
 
 =head1 invalid( [field] )
 
-In an array context, it returns the list of fields which contains invalid value.
+In list context, it returns the list of fields which contains invalid value.
 
 In a scalar context, it returns an hash reference which contains the invalid
 fields as keys, and references to arrays of failed constraints as values.
@@ -542,7 +542,7 @@ sub has_unknown {
 
 =head1 unknown( [field] )
 
-In an array context, it returns the list of fields which are unknown.
+In list context, it returns the list of fields which are unknown.
 In a scalar context, it returns an hash reference which contains the unknown
 fields and their values.
 
@@ -899,9 +899,10 @@ sub _constraint_hash_build {
     die "_constraint_hash_build received wrong number of arguments" unless (scalar @_ == 4);
 
     my  $c = {
-            name        => $constraint_spec,
-            constraint  => $constraint_spec,
-        };
+        name        => undef,
+        constraint  => $constraint_spec,
+    };
+    $c->{name} = $constraint_spec if not ref $constraint_spec;
 
    # constraints can be passed in directly via hash
     if (ref $c->{constraint} eq 'HASH') {
@@ -922,7 +923,9 @@ sub _constraint_hash_build {
     }
     else {
         # provide a default name for the constraint if we don't have one already
-        $c->{name} ||= $c->{constraint};
+        if (not $c->{name} and not ref $c->{constraint}) {
+            $c->{name} ||= $c->{constraint};
+        }
 
         #If untaint is turned on call match_* sub directly.
         if ($untaint_this) {
